<?php

namespace BearlyDigital\ContactForm;

use DateTime;
use Exception;
use Kirby\Cms\Page;
use Kirby\Toolkit\Str;

class HashCash
{
    public static function createChallenge(string $action): string
    {
        $session = kirby()->session();
        return join(":", [
            $session->get("bd.hashTime"),
            $action,
            $session->get("bd.hashValue"),
        ]);
    }

    public static function validateToken(string $token): bool
    {
        $session = kirby()->session();
        $components = explode(":", $token);
        if (intval($components[0]) !== $session->get("bd.hashTime")) {
            throw new HashExpiredException();
        }
        if ($components[2] !== $session->get("bd.hashValue")) {
            return false;
        }
        $check = sha1(
            join(":", [
                $session->get("bd.hashTime"),
                $components[1],
                $session->get("bd.hashValue"),
                $components[3],
            ])
        );
        $valid = true;
        foreach (str_split(substr($check, 0, 4)) as $i) {
            if ($i !== "0") {
                $valid = false;
            }
        }
        return $valid;
    }

    public static function updateSession($forceUpdate = false)
    {
        $session = kirby()->session();
        $time = $session->get("bd.hashTime");
        $value = $session->get("bd.hashValue");
        if (!$time || !$value || $forceUpdate) {
            $session->set("bd.hashTime", time());
            $session->set("bd.hashValue", base64_encode(Str::random(5120)));
        }
    }
}

class HashExpiredException extends Exception
{
}
