// src/event-source.ts
function writeWarnings(result) {
  if (!result?.warnings)
    return;
  for (const warning of result.warnings) {
    if (!warning.location) {
      console.warn(`WARN: ${warning.text}`);
    } else {
      const { file, line, column } = warning.location;
      const pluginText = warning.pluginName ? `[plugin: ${warning.pluginName}] ` : "";
      console.warn(`WARN: ${file}:${line}:${column}: warning: ${pluginText}${warning.text}`);
    }
  }
}
async function init() {
  const { overlay } = await import("./overlay-CDPGLKPJ.js");
  const evt = new EventSource(window.__ESBUILD_LR_PLUGIN__ + "/esbuild");
  let removeOverlay;
  evt.addEventListener("reload", (e) => {
    writeWarnings(JSON.parse(e?.data ?? "{}"));
    console.log("esbuild-plugin-livereload: reloading...");
    location.reload();
  });
  evt.addEventListener("reload-css", (e) => {
    const result = JSON.parse(e?.data ?? "{}");
    writeWarnings(result);
    console.log("esbuild-plugin-livereload: reloading CSS...");
    const links = document.getElementsByTagName("link");
    for (let i = 0; i < links.length; i++) {
      const link = links.item(i);
      if (!link || link.rel !== "stylesheet" || !link.href)
        continue;
      const url = new URL(link.href);
      url.searchParams.set("_hash", Date.now().toString());
      link.href = url.href;
    }
  });
  evt.addEventListener("build-result", (e) => {
    const result = JSON.parse(e?.data ?? "{}");
    writeWarnings(result);
    if (removeOverlay && !result.errors.length) {
      removeOverlay();
      removeOverlay = void 0;
    }
    if (result.errors?.length) {
      removeOverlay = overlay({
        errors: result.errors,
        openFileURL: window.__ESBUILD_LR_PLUGIN__ + "/open-editor"
      });
    }
  });
}
init().catch((e) => {
  console.error("ERROR: Unable to initialize esbuild-plugin-livereload");
  console.error(e.toString());
});
//# sourceMappingURL=livereload-event-source.js.map
