/// <reference types="node" />
import type { Message, Plugin } from 'esbuild';
import type { ServerResponse } from 'http';
export interface ClientMessage {
    /**
     * Does the current message represent a CSS-only update?
     */
    cssUpdate?: boolean;
    /**
     * Error messages.
     */
    errors?: readonly Message[];
    /**
     * Warning messages.
     */
    warnings?: readonly Message[];
}
export interface LivereloadPluginOptions {
    /**
     * Instead of hot-reloading CSS files, trigger a full page reload when CSS is updated.
     *
     * @default false
     */
    fullReloadOnCssUpdates?: boolean;
    /**
     * Port that the livereload server will run on.
     *
     * @default 53099
     */
    port?: number;
    /**
     * Host that the livereload server will run on.
     *
     * @default 127.0.0.1
     */
    host?: string;
}
export declare function livereloadPlugin(options?: LivereloadPluginOptions): Plugin;
/**
 * Notifies connected clients that errors or warnings occurred from
 * a given source. If there are no errors and the notification originates
 * from esbuild, the page will be sent a reload request.
 *
 * @param errorSource - Key to use when identifying these errors and warnings.
 *                      Previous results will be overwritten for the same `errorSource`.
 * @param msg - Object containing errors and warnings from the given source
 * @param connectedClients - Set of long-lived server responses representing
 *                           clients currently connected to the livereload
 *                           server. Only required if you are implementing your
 *                           own livereload server.
 */
export declare function notify(errorSource: string, msg: ClientMessage, connectedClients?: Set<ServerResponse>): void;
//# sourceMappingURL=livereload-plugin.d.ts.map